# pyROGER pacakage
## Installation

As this is a dev version for installing pyROGER package you have to download the source doing:

`git clone https://github.com/Martindelosrios/pyROGER.git`

Then, in the pyROGER directory just do

`pip install .`

Soon you will be able to do

`pip install pyROGER`

## Tutorial

In [Examples](https://github.com/Martindelosrios/pyROGER/tree/dev/EXAMPLES) you can find some examples to start playing with pyROGER
